#!/bin/sh

#--------------------------------------------------------
# faxmailpro.sh (opt_ssmtp v0.8)
#--------------------------------------------------------

#---------------------------------------
# Hilfsfunktionen
#---------------------------------------
#---------------------------------------
# usage ()
#---------------------------------------
usage ()
{
	echo "usage: faxmailpro.sh sff_file"
	echo "       'sff-file' must be specified as an absolute path!"
	echo "       faxmailpro.sh -v"
	echo "       print out some version information"
}

#---------------------------------------
# log (string)
#---------------------------------------
log ()
{
	TEXT=$1

	if [ "${FAXMAILPRO_LOGFILE}" != "" ]; then
		case "${FAXMAILPRO_LOGFILE}"
		in
			syslog) logger "faxmailpro: ${TEXT}";;
			*)      echo "${DATE} faxmailpro: ${TEXT}" >> ${FAXMAILPRO_LOGFILE};;
		esac
	fi
    
	return 1	
}

#---------------------------------------
# getArg (string)
#---------------------------------------
getArg ()
{
	ARG1=$1
	
	if [ "${ARG1}" = "-v" ];
	then
	    echo "faxmailpro.sh version ${VERSION}"
	    exit 0
	else
	    NAME="${ARG1}"
	    return 0
	fi
	return 1
}


#---------------------------------------
# Hilfsvariablen
#---------------------------------------
. /etc/faxmailpro.conf
VERSION='0.8 (2006-07-30)'
NAME=''

#---------------------------------------
# Aufrufparameter einlesen
#---------------------------------------
while test $# -gt 0
do
	getArg "$1"
	if [ "$?" = "1" ];
	then
		break;
	fi
	shift
done

if [ "${NAME}" = "" ];
then
	# fehlender Parameter
	usage
	exit 1
fi

#---------------------------------------
# Konvertierung vorbereiten
#---------------------------------------

VERZEICHNIS=`dirname "${NAME}"`
       NAME=`basename "${NAME}" .sff`
         TO=`basename "${VERZEICHNIS}"`
     TMPDIR=`date '+%Y%m%d%H%M%S'`          # temporaeres Verzeichnis fuer Konvertierung
      DATUM=`date '+%d.%m.%Y %H:%M:%S Uhr'`
     SEITEN=`echo ${NAME} | cut -c 3-5 | sed 's/^[0]*//'`  # Anzahl Seiten feststellen
     SENDER=`echo ${NAME} | cut -c 14-`  # Sender feststellen
SENDER_KLAR=`sed 's/,[^,]*$//' /etc/phonebook | grep "^${SENDER}=" | cut -d"=" -f 2-`  # Klartextname feststellen ueber /etc/phonebook

if [ "${SENDER_KLAR}" = "" ];
then
	SENDER_KLAR=${SENDER}" (unbekannt)"
fi
           
cd "${VERZEICHNIS}"
mkdir -p "${TMPDIR}"
if [ -d "${TMPDIR}" ];
then
    # das temporaere Verzeichnis existiert
    #-------------------------------
    # Beginne mit der Konvertierung
    #-------------------------------
    
    # nur auf Kopie arbeiten
    cp "${NAME}.sff" "${TMPDIR}"
    cd "${TMPDIR}"
    
    #--------------------
    # konvertiere nach (mehrseitiges) TIFF
    #--------------------
    if [ "${FAXMAILPRO_PDF}" = "yes" -o "${FAXMAILPRO_PNG}" = "yes" ]; then
    	sfftobmp -q -f -t "${NAME}.sff"
		rm "${NAME}.sff"
    fi
    
    #--------
    # PDF
    #--------
    if [ "${FAXMAILPRO_PDF}" = "yes" ]; then
    	tiff2pdf "${NAME}.tif" -o "${NAME}.pdf"
    fi
    #--------
    # PNG
    #--------
    if [ "${FAXMAILPRO_PNG}" = "yes" ]; then
        PAGE="1"
        while [ ${PAGE} -le ${SEITEN} ];
        do
    		tiff2png "${NAME}.tif" "${NAME}_${PAGE}.png" -p ${PAGE}
    		PAGE=`expr ${PAGE} + 1`
    	done
    fi
    	
    #-------------------------------
    # Konvertierung beendet
    #-------------------------------
    rm "${NAME}.tif" 2> /dev/null
    
    #-------------------------------
    # Bodytext erstellen
    #-------------------------------
	(
		echo -e "Fax von     : ${SENDER_KLAR}\r"
		echo -e "Faxnummer   : ${SENDER}\r"
		echo -e "Datum       : ${DATUM}\r"
		echo -e "Seiten      : ${SEITEN}\r"
	) > body.txt

    #-----------------------------------
    # als Mail versenden (via opt_ssmtp)
    #-----------------------------------
    ssmtp.sh -f "${FAXMAILPRO_FROM}@${FAXMAILPRO_DOMAIN}" -t "${TO}@${FAXMAILPRO_DOMAIN}" -r "${FAXMAILPRO_REPLY_TO}@${FAXMAILPRO_DOMAIN}" -s "Fax von ${SENDER_KLAR}, ${SEITEN} Seite(n)" -b "${VERZEICHNIS}/${TMPDIR}/body.txt" -d "${VERZEICHNIS}/${TMPDIR}" -rn "^body.txt$"
    
    #-------------------------------
    # letztes aufraeumen
    #-------------------------------
    cd ..
    rm -rf "${TMPDIR}"
    
    # fertig!
else
    log "Cannot create temporary directory. Will quit now ..."
    exit 1
fi

#-------------------------------
# abschliessende Arbeiten
#-------------------------------
#mv "${NAME}" "${NAME}.sff"
#chmod u+rw "${NAME}.sff"
#gzip "${NAME}.sff"

#echo "`date '+%d.%m.%y'` `date '+%H:%M:%S'` ${SENDER} ${SEITEN} ${NAME}.sff" >> mfax.log

exit 0
